cf\_units
=========

.. image:: https://api.travis-ci.org/SciTools/cf_units.png
   :target: http://travis-ci.org/SciTools/cf_units

\(C) British Crown Copyright 2010 - 2015, Met Office

Units of measure as required by the Climate and Forecast (CF) metadata
conventions.

Provision of a wrapper class to support Unidata/UCAR UDUNITS-2, and the
netcdftime calendar functionality.


Code
----
cf_units is licenced under the GNU Lesser General Public License (LGPLv3).
The full text of the licence can be found in the COPYING and COPYING.LESSER
files.

Development occurs at https://github.com/SciTools/cf_units.


See also:
`UDUNITS-2 <http://www.unidata.ucar.edu/software/udunits/udunits-2/udunits2.html>`__
